@@ -1,11 +1,14 @@
-import yaml
 from collections import OrderedDict
+
+import yaml
 from valohai_yaml.objs import Config
 
 # https://stackoverflow.com/questions/42518067/how-to-use-ordereddict-as-an-input-in-yaml-dump-or-yaml-safe-dump
 yaml.add_representer(
     OrderedDict,
-    lambda dumper, data: dumper.represent_mapping('tag:yaml.org,2002:map', data.items())
+    lambda dumper, data: dumper.represent_mapping(
+        "tag:yaml.org,2002:map", data.items()
+    ),
 )
 
 
